@@ -1,4 +1,4 @@
-from sdk.data_type import ConfigItem, SpatialProps
+from ipa.data_type import ConfigItem, SpatialProps
 
 
 def test_config_item():
